==> libsbml_5.17.2+dfsg.orig.tar.xz: libSBML-5.17.2-Source/src/bindings/r/local-downcast-plugins-distrib.cpp <==
/**
 * @file local-downcast-plugins-distrib.cpp
 * @brief Casting to most specific plugins object for r
 * @author SBMLTeam
 *
 * <!--------------------------------------------------------------------------
 * This file is part of libSBML. Please visit http://sbml.org for more
 * information about SBML, and the latest version of libSBML.
 *
 * Copyright (C) 2013-2018 jointly by the following organizations:
 * 1. California Institute of Technology, Pasadena, CA, USA
 * 2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
 * 3. University of Heidelberg, Heidelberg, Germany
 *
 * Copyright (C) 2009-2013 jointly by the following organizations:
 * 1. California Institute of Technology, Pasadena, CA, USA
 * 2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
 *
 * Copyright (C) 2006-2008 by the California Institute of Technology,
 * Pasadena, CA, USA
 *
 * Copyright (C) 2002-2005 jointly by the following organizations:
 * 1. California Institute of Technology, Pasadena, CA, USA
 * 2. Japan Science and Technology Agency, Japan
 *
 * This library is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as published by the
 * Free Software Foundation. A copy of the license agreement is provided in the
 * file named "LICENSE.txt" included with this software distribution and also
 * available online as http://sbml.org/software/libsbml/license.html
 * ------------------------------------------------------------------------ -->
 */


#ifdef USE_DISTRIB
if (pkgName == "distrib")
{
  if (sb->getTypeCode() == SBML_FUNCTION_DEFINITION)
  {
    return SWIGTYPE_p_DistribFunctionDefinitionPlugin;
  }
  else if (sb->getTypeCode() == SBML_DOCUMENT)
  {
    return SWIGTYPE_p_DistribSBMLDocumentPlugin;
  }
  else
  {
    return SWIGTYPE_p_DistribSBasePlugin;
  }
}

#endif // USE_DISTRIB

==> libsbml_5.18.0+dfsg.orig.tar.xz: libSBML-5.18.0-Source/src/bindings/r/local-downcast-plugins-distrib.cpp <==
/**
 * @file local-downcast-plugins-distrib.cpp
 * @brief Casting to most specific plugins object for r
 * @author SBMLTeam
 *
 * <!--------------------------------------------------------------------------
 * This file is part of libSBML. Please visit http://sbml.org for more
 * information about SBML, and the latest version of libSBML.
 *
 * Copyright (C) 2019 jointly by the following organizations:
 * 1. California Institute of Technology, Pasadena, CA, USA
 * 2. University of Heidelberg, Heidelberg, Germany
 *
 * Copyright (C) 2013-2018 jointly by the following organizations:
 * 1. California Institute of Technology, Pasadena, CA, USA
 * 2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
 * 3. University of Heidelberg, Heidelberg, Germany
 *
 * Copyright (C) 2009-2013 jointly by the following organizations:
 * 1. California Institute of Technology, Pasadena, CA, USA
 * 2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
 *
 * Copyright (C) 2006-2008 by the California Institute of Technology,
 * Pasadena, CA, USA
 *
 * Copyright (C) 2002-2005 jointly by the following organizations:
 * 1. California Institute of Technology, Pasadena, CA, USA
 * 2. Japan Science and Technology Agency, Japan
 *
 * This library is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as published by the
 * Free Software Foundation. A copy of the license agreement is provided in the
 * file named "LICENSE.txt" included with this software distribution and also
 * available online as http://sbml.org/software/libsbml/license.html
 * ------------------------------------------------------------------------ -->
 */


#ifdef USE_DISTRIB
if (pkgName == "distrib")
{
  if (sb->getTypeCode() == SBML_DOCUMENT)
  {
    return SWIGTYPE_p_DistribSBMLDocumentPlugin;
  }
  else
  {
    return SWIGTYPE_p_DistribSBasePlugin;
  }
}

#endif // USE_DISTRIB
